@@ -6,16 +6,17 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-import inspect
 from typing import Any
 from typing import Callable
 from typing import Coroutine
 
 import fastapi
+import fastapi.exceptions
 import fastapi.routing
 from fastapi.dependencies.utils import get_body_field
 from fastapi.dependencies.utils import get_dependant
 
+from .errorhandler import ErrorHandler
 from .types import Request
 
 
@@ -59,7 +60,7 @@ class APIRoute(fastapi.routing.APIRoute):
             # getting the model.
             async def f(dto: Model) -> Any: pass # type: ignore
             self.body_field = get_body_field(
-                dependant=get_dependant(path=self.path_format, call=f),
+                dependant=get_dependant(path=self.path_format, call=f), # type: ignore
                 name=self.unique_id
             )
 
@@ -69,8 +70,12 @@ class APIRoute(fastapi.routing.APIRoute):
         super_handler = super().get_route_handler()
 
         async def handler(request: fastapi.Request) -> fastapi.Response:
-            return await super_handler(
-                Request(request.scope, request.receive)
-            )
+            errors = ErrorHandler(request)
+            try:
+                return await super_handler(
+                    Request(request.scope, request.receive)
+                )
+            except fastapi.exceptions.RequestValidationError as exception:
+                return await errors.handle(exception)
 
         return handler
\ No newline at end of file
