@@ -323,7 +323,8 @@ class Endpoint(IEndpoint, metaclass=EndpointMetaclass):
                 is_detail=False,
                 model=cls.model,
                 name=cls.name,
-                summary=cls.summary
+                summary=cls.summary,
+                tags=cls.tags
             )
             options.add_to_router(
                 app=app,
