@@ -8,9 +8,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 from .debugtransport import DebugTransport
 from .aortaendpoint import AortaEndpoint
-from .eventarcendpoint import EventarcEndpoint
 from .cloudschedulerendpoint import CloudSchedulerEndpoint
+from .eventarcendpoint import EventarcEndpoint
 from .googleendpoint import GoogleEndpoint
+from .googletransport import GoogleTransport
+from .service import Service
 from .serviceaccountprincipal import ServiceAccountPrincipal
 
 
@@ -20,5 +22,7 @@ __all__: list[str] = [
     'DebugTransport',
     'EventarcEndpoint',
     'GoogleEndpoint',
+    'GoogleTransport',
+    'Service',
     'ServiceAccountPrincipal'
 ]
