@@ -3,6 +3,8 @@
 # All rights reserved. No warranty, explicit or implicit, provided. In
 # no event shall the author(s) be liable for any claim or damages.
 """Declares :class:`GoogleEndpoint`."""
+import os
+
 import fastapi
 import fastapi.params
 import httpx
@@ -41,6 +43,8 @@ class GoogleEndpoint(Endpoint):
 
     #: The set of subjects that are accepted by this endpoint.
     service_accounts: set[str] | None = None
+    if os.getenv('GOOGLE_SERVICE_ACCOUNT_EMAIL'):
+        service_accounts = {os.environ['GOOGLE_SERVICE_ACCOUNT_EMAIL']}
 
     @classmethod
     async def principal_factory(
