@@ -23,6 +23,9 @@ __all__ = [
     'Provider'
 ]
 
+def environment(name: str) -> Any:
+    return Environment(name)
+
 def instance(dependency: type[Any] | str) -> Any:
     return Instance(dependency)
 
@@ -36,16 +39,6 @@ def is_satisfied(name: str, using: Provider | None = None) -> bool:
     return (using or _default).is_satisfied(name)
 
 
-async def on_boot(*args: Any, using: Provider | None = None, **kwargs: Any) -> None:
-    """Provides a hook to execute logic when booting an application."""
-    await (using or _default).on_boot(*args, **kwargs)
-
-
-async def on_shutdown(*args: Any, using: Provider | None = None, **kwargs: Any) -> None:
-    """Provides a hook to execute logic when shutting down an application."""
-    await (using or _default).on_shutdown(*args, **kwargs)
-
-
 def provide(
     name: str,
     value: object,
@@ -65,3 +58,13 @@ def provide(
 def resolve(name: str, using: Provider | None = None) -> typing.Any:
     """Resolve a priorly injected dependency by its name."""
     return (using or _default).resolve(name)
+
+
+async def on_boot(*args: Any, using: Provider | None = None, **kwargs: Any) -> None:
+    """Provides a hook to execute logic when booting an application."""
+    await (using or _default).on_boot(*args, **kwargs)
+
+
+async def on_shutdown(*args: Any, using: Provider | None = None, **kwargs: Any) -> None:
+    """Provides a hook to execute logic when shutting down an application."""
+    await (using or _default).on_shutdown(*args, **kwargs)
\ No newline at end of file
