@@ -40,6 +40,7 @@ from .types import ITokenIssuer
 from .types import IUpstreamProvider
 from .types import IUpstreamReturnHandler
 from .types import ServerMetadata
+from .types import TokenException
 from .tokenissuer import TokenIssuer
 from .tokenrequesthandler import TokenRequestHandler
 
@@ -130,7 +131,6 @@ class AuthorizationServer(fastapi.APIRouter, IOpenAuthorizationServer):
             base_path='/.well-known/oauth-authorization-server',
             cors_policy=cbra.cors.AnonymousReadCorsPolicy,
             name='oauth2.metadata',
-            tags=DEFAULT_TAGS,
             response_model_exclude_defaults=True
         )
         if self.authorize is not None and self.enable_authorization:
@@ -182,6 +182,7 @@ class AuthorizationServer(fastapi.APIRouter, IOpenAuthorizationServer):
             tags=DEFAULT_TAGS
         )
         app.add_exception_handler(Error, self.on_oauth2_exception) # type: ignore
+        app.add_exception_handler(TokenException, self.on_token_exception) # type: ignore
         app.add_event_handler('startup', self.setup_authorization_server) # type: ignore
 
         assert app.openapi_tags is not None # nosec
@@ -385,4 +386,11 @@ class AuthorizationServer(fastapi.APIRouter, IOpenAuthorizationServer):
         request: fastapi.Request,
         exception: Error
     ) -> fastapi.Response:
-        return await exception.as_response(request, error_url=self.error_url)
\ No newline at end of file
+        return await exception.as_response(request, error_url=self.error_url)
+
+    async def on_token_exception(
+        self,
+        request: fastapi.Request,
+        exception: TokenException
+    ) -> fastapi.Response:
+        return exception.as_response()
\ No newline at end of file
