@@ -9,5 +9,7 @@ class ClientSubject(ISubject):
     __module__: str = 'cbra.ext.oauth2'
 
     def __init__(self, client_id: str, **kwargs: Any):
-        kwargs['sub'] = client_id
-        super().__init__(**kwargs)
\ No newline at end of file
+        self.sub = client_id
+
+    def get_identifier(self, public: bool = False) -> int:
+        return self.sub
\ No newline at end of file
