@@ -2,6 +2,7 @@
 from typing import Any
 from typing import Coroutine
 
+import pydantic
 from ckms.core.models import JSONWebSignature
 from ckms.types import JSONWebKeySet
 from ckms.types import JSONWebKey
@@ -9,9 +10,10 @@ from ckms.types import JSONWebKey
 from cbra.ext.oauth2.types import BaseSubject
 
 
-class Subject(BaseSubject):
+class Subject(BaseSubject, pydantic.BaseModel):
     sub: str
     keys: list[JSONWebKey] = []
+    client_id: str | None
 
     @property
     def jwks(self) -> JSONWebKeySet:
