@@ -6,7 +6,6 @@ import fastapi
 import httpx
 from ckms.core import Keychain
 from ckms.jose import PayloadCodec
-from ckms.types import ClaimSet
 from ckms.types import JSONWebKeySet
 from ckms.types import ServerMetadata
 from fastapi.security import HTTPBearer
@@ -47,8 +46,9 @@ def RFC9068Principal(
     header: str = 'Authorization',
     path: typing.Optional[str] = None,
     max_age: int = 300,
-    principal_factory: typing.Callable[[ClaimSet], IPrincipal] = Principal.fromclaimset,
-    scope: set[str] | None = None
+    principal_factory: typing.Callable[[typing.Any], IPrincipal] = Principal.fromclaimset,
+    scope: set[str] | None = None,
+    null: type[IPrincipal] | None = None
 ) -> typing.Any:
     """Resolves the principal in a request to a subject using an
     :rfc:`9068` access token.
@@ -73,7 +73,7 @@ def RFC9068Principal(
             if auto_error:
                 # The header was present but a parsing error occurred.
                 raise InvalidAuthorizationScheme
-            return None
+            return null or None
 
         if str.lower(bearer.scheme or '') != "bearer":
             raise InvalidAuthorizationScheme
@@ -97,7 +97,7 @@ def RFC9068Principal(
             x for x in str.split((claims.extra.get('scope') or ''), ' ')
             if x
         }
-        if not (granted_scope > scope):
+        if not (granted_scope >= scope):
             raise CanonicalException(
                 http_status_code=401,
                 code="AUTHORIZATION_REQUIRED",
