@@ -12,6 +12,7 @@ import pydantic
 from fastapi.params import Query
 from pydantic.fields import FieldInfo
 
+from .accesstype import AccessType
 from .iprincipal import IPrincipal
 from .redirecturl import RedirectURL
 from .responsetype import ResponseType
@@ -23,6 +24,7 @@ class BaseAuthorizationRequest:
     redirect_uri: str | None
     scope: str | None
     state: str | None
+    access_type: AccessType
     response_mode: str | None
     resource: str | None
     nonce: str | None
@@ -52,6 +54,7 @@ class BaseAuthorizationRequest:
             'redirect_uri': str | None,
             'scope': str | None,
             'state': str | None,
+            'access_type': AccessType,
             'response_mode': str | None,
             'resource': str | None,
             'nonce': str | None,
@@ -123,6 +126,20 @@ class BaseAuthorizationRequest:
                 ),
                 example=bytes.hex(os.urandom(8))
             ),
+            'access_type': field_factory(
+                default=AccessType.online,
+                title="Access type",
+                description=(
+                    "Indicates whether your application can refresh access tokens "
+                    "when the user is not present at the browser. Valid parameter "
+                    "values are `online`, which is the default value, `and offline`.\n\n"
+                    "Set the value to `offline` if your application needs to refresh "
+                    "access tokens when the user is not present at the browser. "
+                    "This value instructs the authorization server to return a "
+                    "refresh token and an access token the first time that your "
+                    "application exchanges an authorization code for tokens."
+                )
+            ),
             'response_mode': field_factory(
                 default=None,
                 title="Response mode",
