@@ -7,6 +7,7 @@ from .authorizationcodegrant import AuthorizationCodeGrant
 from .basegrant import BaseGrant
 from .clientcredentialsgrant import ClientCredentialsGrant
 from .jwtbearerassertiongrant import JWTBearerAssertionGrant
+from .refreshtokengrant import RefreshTokenGrant
 from .sessiongrant import SessionGrant
 
 
@@ -17,6 +18,7 @@ class TokenRequestParameters(pydantic.BaseModel):
         AuthorizationCodeGrant,
         ClientCredentialsGrant,
         JWTBearerAssertionGrant,
+        RefreshTokenGrant,
         SessionGrant
     ]
 
