@@ -9,10 +9,12 @@
 import fastapi
 
 from .clientkeysendpoint import ClientKeysEndpoint
+from .persistencesecurity import PersistenceSecurity
 from .personaldatahandler import PersonalDataHandler
 from .resource import Resource
 from .service import Service
 from .serviceclient import ServiceClient
+from .serviceresource import ServiceResource
 
 
 __all__: list[str] = [
@@ -21,7 +23,8 @@ __all__: list[str] = [
     'PersonalDataHandler',
     'PersonalDataService',
     'Service',
-    'ServiceClient'
+    'ServiceClient',
+    'ServiceResource'
 ]
 
 
